Quick Start
===================

Platform Support
----------------------

``cr-nimble`` can run on any platform supported by ``JAX``. 
We have tested ``cr-nimble`` on Mac and Linux platforms.

``JAX`` is not officially supported on Windows platforms at the moment. 
Although, it is possible to build it from source using Windows Subsystems for Linux.


Installation
-------------------------------

Installation from PyPI:

.. code:: shell

    python -m pip install cr-nimble



Directly from our GITHUB repository:

.. code:: shell

    python -m pip install git+https://github.com/carnotresearch/cr-nimble.git


Examples
----------------
